@@ -1,7 +1,7 @@
 #!/bin/sh 
 # define HISTFILE0; final assembled hist file (binary)
 #        HISTFILET; temporary  hist file
-HISTFILE0=./p18eVcos1.0.hist
+HISTFILE0=./$EXECID.hist
 export HISTFILE0
 HISTFILET=./temp.hist
 export HISTFILET
