@@ -21,7 +21,7 @@
       read(input, *) recxy, tklat, tkelosslat, tkrespec,
      *  tkrzspec, tkzfspec,  tkrfspec, tkefspec,
      *  tkretspec, tkrtspec,
-     *  tkrezspec, tkrzfspec, tkrefspec
+     *  tkrezspec, tkrzfspec, tkrefspec, tkarspec
 
       binw = 2
 
