@@ -35,7 +35,13 @@ c
        real*8 g, pmu
 
            g=pion.fm.p(4)/maspic
-           pmu=sqrt(muon.fm.p(4)**2- masmu2)
+           pmu = muon.fm.p(4)**2- masmu2
+c//////////////////
+           if(pmu .lt. 0.) then
+              write(*,*) ' pmu =',pmu, muon.fm.p(4), muon.mass
+           endif
+c///////////////
+           pmu=sqrt(pmu)
            polari=(muon.fm.p(4) * est - g * masmu2)/pmu/pst
            if(muon.charge .gt. 0) then
                polari = -polari
