@@ -156,6 +156,8 @@ cc        if(pj.fm.p(4)  .lt. Elund) then
 c            h-A collision  Fermi momentum is considered inside
       if( ActiveMdl .eq. 'dpmjet3') then
          call cdpmjet(pj, ia, iz, a, ntp)
+      elseif( ActiveMdl .eq. 'qgsjet2') then
+         call cQGSjet(pj, ia, iz, a, ntp)
       elseif( ActiveMdl .eq. 'fritiof1.6' .or. 
      *        ActiveMdl .eq. 'nucrin') then
             call chALund(pj, ia, iz, a, ntp)
