@@ -61,10 +61,11 @@ c     integer ndummy
       character*128 title
       character*96 evid(nsites)
       save evid
-      real*8 cog, sumne,  obstimes, Savederg(5)
+      real*8 cog, cog2, sumne,  obstimes, Savederg(5)
+      real*8 depth
       logical dosort
       character*2  kd(3)
-      save obstimes
+      save obstimes,  depth
 
 c       keep this interface so that the difference between
 c       the one in ForTA/  and in FleshHist is in the next line
@@ -389,12 +390,14 @@ c     *  eneded at this moment.
 c     *  After this is executed, event generation starts.
 c     *
       entry xBgEvent
-
-
       call cqIncident(inci, angle)
-      write(*,'("i ",  i3,  i4, g13.4,3f11.7)') EventNo, inci.p.code,
-     *   inci.p.fm.e,  -angle.r(1),  -angle.r(2), -angle.r(3)      
-c      
+
+       write(*,'("i ",  i3,  i4, g13.4,3f11.7,f7.1)')
+     *    EventNo, inci.p.code,
+     *   inci.p.fm.e,  -angle.r(1),  -angle.r(2), -angle.r(3)
+
+
+
       do i = 1, NoOfASSites
          SumEloss(i) = 0.
          Ng(i) = 0.
@@ -524,6 +527,8 @@ c     For id =2, you need not output the z value, because it is always
 c     0 (within the computational accuracy).
 c
 c     **************************
+
+
       obstimes = obstimes + 1.d0
       if(mod(obstimes, 100000.d0) .eq. 0. ) then 
          dosort=.false.
@@ -782,6 +787,8 @@ c                  re spectrum
 c     **************
       entry xEnEvent
 c     **************
+      call cqFirstID(depth)
+      depth = depth* 0.1     ! in g/cm2  First col depth.
 
       if(ObserveAS) then
          cog = 0.
@@ -792,27 +799,55 @@ c     **************
          enddo
          cog = cog/sumne
 
+         cog2 = 0.
+         sumne = 0.
+         do i = 1, NoOfASSites
+            if( ASObsSites(i).age .gt.
+     *          (2.0-ASObsSites(NoOfASSites).age))  then
+               cog2 = cog2 + ASObsSites(i).esize*ASDepthList(i)*0.1
+               sumne= sumne +ASObsSites(i).esize
+            endif
+         enddo
+         if(sumne .gt. 0.) then
+            cog2 = cog2/sumne
+         else
+c              too deep penetrate
+            cog2 = ASDepthList(NoOfASSites)*0.1
+         endif
+
+
+         if(fnoB .ge. 0 )  then
+            write(fnoB,
+     *      '("h ", i4,  3i3, 1pE11.3, 0p 3f11.7, f7.2, 2f7.0)')
+     *      EventNo,  inci.p.code,
+     *      inci.p.subcode, inci.p.charge,
+     *      inci.p.fm.e, -angle.r(1), -angle.r(2), -angle.r(3),
+     *      depth, cog, cog2
+         else
+            write(*,
+     *      '("h ", i4,  3i3, 1pE11.3, 0p 3f11.7, f7.2, 2f7.0)')
+     *      EventNo,  inci.p.code,
+     *      inci.p.subcode, inci.p.charge,
+     *      inci.p.fm.e, -angle.r(1), -angle.r(2), -angle.r(3),
+     *      depth, cog, cog2
+         endif
          do i = 1, NoOfASSites 
             if(fnoB .ge. 0) then
-               write(fnoB, '( i4, i3, i5,
-     *          1pE11.3, 0pf5.2, f5.2, 1pE11.3, 0pf7.1,
-     *          1p4E11.3, 0pf7.0)')
-     *          EventNo, i,
-     *          int( ASDepthList(i)*0.1 ),  
-     *          sngl(ASObsSites(i).esize), sngl(ASObsSites(i).age),
-     *          ASDepthList(i)*0.1/cog, SumEloss(i),  
-     *          sngl(ASObsSites(i).mu), Ng(i), Ne(i), Nmu(i),
-     *          Nhad(i), cog
+               write(fnoB, '("t ", i3, 2f7.1,  2f6.3,
+     *         1p6E11.3)')
+     *          i, 
+     *          ASDepthList(i)*0.1,  ASObsSites(i).mu,
+     *          ASObsSites(i).age,   ASDepthList(i)*0.1/cog2, 
+     *          Ng(i), Ne(i), Nmu(i), Nhad(i),
+     *          ASObsSites(i).esize, SumEloss(i)  
             else
-               write(*, '( i4, i3, i5,
-     *          1pE11.3, 0pf5.2, f5.2, 1pE11.3, 0pf7.1,
-     *          1p4E11.3, 0pf7.0)')
-     *          EventNo, i,
-     *          int( ASDepthList(i)*0.1 ),  
-     *          sngl(ASObsSites(i).esize), sngl(ASObsSites(i).age),
-     *          ASDepthList(i)*0.1/cog, SumEloss(i),  
-     *          sngl(ASObsSites(i).mu), Ng(i), Ne(i), Nmu(i), 
-     *          Nhad(i), cog
+               write(*, '("t ", i3, 2f7.1,  2f6.3,
+     *         1p6E11.3)')
+     *          i, 
+     *          ASDepthList(i)*0.1,  ASObsSites(i).mu,
+     *          ASObsSites(i).age,   ASDepthList(i)*0.1/cog2, 
+     *          Ng(i), Ne(i), Nmu(i), Nhad(i),
+     *          ASObsSites(i).esize, SumEloss(i)  
             endif
          enddo
       endif
@@ -828,8 +863,8 @@ c     **************
      *   '(i3, i5,  f5.2, f5.2,
      *   i5,  i4)')
      *   histdep(i), int( ASDepthList(j)*0.1 ),  
-     *   ASObsSites(j).age, ASDepthList(j)*0.1/cog,
-     *   int(ASObsSites(j).mu), int(cog)
+     *   ASObsSites(j).age, ASDepthList(j)*0.1/cog2,
+     *   int(ASObsSites(j).mu), int(cog2)
       enddo
 
 
