@@ -1,7 +1,7 @@
 c           life time in s
         real*8  t0pi, t0k, t0mu, t0ks, t0kl, t0pi0, t0d0, t0dc
         real*8  t0sigmap, t0sigmam, t0sigma0, t0gzai0, t0gzaim
-        real*8  t0lambda, t0lambdac, t0eta
+        real*8  t0lambda, t0lambdac, t0eta, t0bomega
 
 c           decay width in GeV
         real*8  wrho, womega, wphai
@@ -18,7 +18,8 @@ c           decay width in GeV
      5  t0gzaim = 1.641d-10,
      6  t0lambda = 2.623d-10,
      7  t0lambdac = 2.3d-13,
-     8  t0eta     = 7.5d-19 )
+     8  t0eta     = 7.5d-19,
+     9  t0bomega  = 0.822d-10 )
 
        parameter (
      4  wrho=150.d-3, womega=8.4d-3,
